| summary.dec.sim | R Documentation |
summary method for class "dec.sim".
## S3 method for class 'dec.sim'
summary(object, pt, ...)
object |
An object of class |
pt |
Target toxicity for each scenario. |
... |
Unused arguments. |
summary formats key statistics from dose-finding
simulations. Given the target toxicity, it reports the probability of
selecting each dose level as the MTD, the probability of selecting doses
above the true MTD, the probability of selecting the true MTD, and the
probability that subjects are treated at or below the true MTD. The true
MTD is defined as the highest dose level with toxicity probability less
than or equal to the target toxicity. If the target is below the smallest
toxicity probability, the lowest dose level is treated as the MTD. For
example, if the target is 0.3 and the true toxicity probabilities for five
doses are 0.1, 0.25, 0.35, 0.40, and 0.50, then the MTD is dose 2.
test.file <- system.file("extdata", "testS.csv", package = "tsdf")
dt <- dec.table(0.6,0.4,0.2,0.3,c(3,3,3))
out <- sl.sim(dt$table, test.file)
pt <- c(0.3, 0.4)
summary(out, pt)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.